#
# spec file for package python3-virtualenv
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-virtualenv
Version:        13.1.2
Release:        2.20
Url:            http://www.virtualenv.org/
Summary:        Virtual Python Environment builder
License:        MIT
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/v/virtualenv/virtualenv-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%if 0%{?suse_version} <= 1310
# pip is built-in for python 3.4
BuildRequires:  python3-pip
Requires:       python3-pip
%endif
Requires:       python3-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%description
virtualenv is a tool to create isolated Python environments.
The basic problem being addressed is one of dependencies and versions, and
indirectly permissions. Imagine you have an application that needs version 1
of LibFoo, but another application requires version 2. How can you use both
these applications? If you install everything into
/usr/lib/python2.4/site-packages (or whatever your platforms standard location
is), its easy to end up in a situation where you unintentionally upgrade an
application that shouldnt be upgraded.

Or more generally, what if you want to install an application and leave it be?
If an application works, any change in its libraries or the versions of those
libraries can break the application.

Also, what if you cant install packages into the global site-packages
directory? For instance, on a shared host.

In all these cases, virtualenv can help you. It creates an environment that
has its own installation directories, that doesnt share libraries with other
virtualenv environments (and optionally doesnt use the globally installed
libraries either).

%prep
%setup -q -n virtualenv-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
# Remove script copy and replace with symlink to please u-a:
rm %{buildroot}%{_bindir}/virtualenv
ln -s %{_bindir}/virtualenv-%{py3_ver} %{buildroot}%{_bindir}/virtualenv

%pre
# Since /usr/bin/virtualenv became ghosted to be used with update-alternatives, we have to
# get rid of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/virtualenv ] || rm -f %{_bindir}/virtualenv

%post
update-alternatives \
    --install %{_bindir}/virtualenv virtualenv %{_bindir}/virtualenv-%{py3_ver} 30

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove virtualenv %{_bindir}/virtualenv-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc LICENSE.txt README.rst
%ghost %{_bindir}/virtualenv
%{_bindir}/virtualenv-%{py3_ver}
%{python3_sitelib}/virtualenv-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/virtualenv.py
%{python3_sitelib}/virtualenv_support
%{python3_sitelib}/__pycache__/virtualenv.*
%if 0%{?suse_version} >= 1230
%ghost %{_sysconfdir}/alternatives/virtualenv
%endif

%changelog
* Sun Aug 23 2015 arun@gmx.de
- update to version 13.1.2:
  * Upgrade pip to 7.1.2.
- changes from version 13.1.1:
  * Upgrade pip to 7.1.1.
  * Upgrade setuptools to 18.2.
  * Make the activate script safe to use when bash is running with -u.
* Tue Jul 28 2015 toddrme2178@gmail.com
- Don't depend on pip for python >= 3.4, since it is built-in.
* Tue Jul 28 2015 toddrme2178@gmail.com
- Split documentation into a separate subpackage to avoid a
  dependency loop.
* Thu Jul  2 2015 jacobwinski@gmail.com
- update to version 13.1.0
  * Upgrade pip to 7.1.0
  * Upgrade setuptools to 18.0.1
- changes from version 13.0.3
  * Upgrade pip to 7.1.0
  * Upgrade setuptools to 18.0.1
* Tue Jun  2 2015 arun@gmx.de
- update to version 13.0.3:
  * Upgrade pip to 7.0.3
- changes from version 13.0.2:
  * Upgrade pip to 7.0.2
  * Upgrade setuptools to 17.0
* Mon May 25 2015 arun@gmx.de
- update to version 13.0.1:
  * Upgrade pip to 7.0.1
- changes from version 13.0.0:
  * Automatically install wheel when creating a new virutalenv. This
    can be disabled by using the --no-wheel option.
  * Don’t trust the current directory as a location to discover files
    to install packages from.
  * Upgrade setuptools to 16.0.
  * Upgrade pip to 7.0.0.
* Tue Apr  7 2015 arun@gmx.de
- update to version 12.1.1:
  * Upgrade pip to 6.1.1
- changes from version 12.1.0:
  * Upgrade setuptools to 15.0
  * Upgrade pip to 6.1.0
* Thu Feb  5 2015 arun@gmx.de
- update to version 12.0.7:
  * Upgrade pip to 6.0.8
* Sat Jan 31 2015 arun@gmx.de
- update to version 12.0.6:
  * Upgrade pip to 6.0.7
  * Upgrade setuptools to 12.0.5
* Sun Jan  4 2015 arun@gmx.de
- specfile: update copyright year
- update to version 12.0.5:
  * Upgrade pip to 6.0.6
  * Upgrade setuptools to 11.0
* Wed Dec 31 2014 arun@gmx.de
- update to version 12.0.4:
  * Revert the fix to "-p" on Debian based pythons as it was broken in other
    situations.
  * Revert several sys.path changes new in 12.0 which were breaking virtualenv.
- changes from version 12.0.3:
  * Fix an issue where Debian based Pythons would fail when using -p with the
    host Python.
  * Upgrade pip to 6.0.3
- changes from version 12.0.2:
  * Upgraded pip to 6.0.2
- changes from version 12.0.1:
  * Upgraded pip to 6.0.1
- changes from version 12.0 :
  * **PROCESS** Version numbers are now simply "X.Y" where the leading `"1"
    has been dropped.
  * Split up documentation into structured pages
  * Now using pytest framework
  * Correct sys.path ordering for debian, issue #461
  * Correctly throws error on older Pythons, issue #619
  * Allow for empty $PATH, pull #601
  * Don't set prompt if $env:VIRTUAL_ENV_DISABLE_PROMPT is set for Powershell
  * Updated setuptools to 7.0
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Jul  3 2014 speilicke@suse.com
- Update to version 1.11.6:
  + Updated setuptools to 3.5
  + Updated pip to 1.5.6
- Changes from version 1.11.5:
  + Updated setuptools to 3.4.4
  + Updated documentation to use https://virtualenv.pypa.io/
  + Updated pip to 1.5.5
* Sun Mar 30 2014 toddrme2178@gmail.com
- update to 1.11.4
  * Updated pip to 1.5.4
- update to 1.11.3
  * Updated setuptools to 2.2
  * Updated pip to 1.5.3
* Tue Feb 11 2014 dmueller@suse.com
- update to 1.11.2:
  * Fixed easy_install installed virtualenvs by updated pip to 1.5.2
  * Fixed an issue where pip and setuptools were not getting installed when using
  the ``--system-site-packages`` flag.
  * Updated setuptools to fix an issue when installed with easy_install
  * Fixed an issue with Python 3.4 and sys.stdout encoding being set to ascii
* Wed Jan  8 2014 speilicke@suse.com
- Update to version 1.11:
  + BACKWARDS INCOMPATIBLE Switched to using wheels for the bundled
    copies of setuptools and pip. Using sdists is no longer supported
  + BACKWARDS INCOMPATIBLE Modified the handling of --extra-search-dirs.
    This option now works like pip’s --find-links option, in that it
    adds extra directories to search for compatible wheels for pip and
    setuptools. The actual wheel selected is chosen based on version
    and compatibility, using the same algorithm as pip install setuptools.
  + Upgraded pip to v1.5
  + Upgraded setuptools to v1.4
- Symlink /usr/bin/virtualenv in buildroot (u-a warning) and ghost
  alternatives link on 12.3 or newer
* Fri Oct 11 2013 speilicke@suse.com
- Update to version 1.10.1:
  + **New Signing Key** Release 1.10.1 is using a different key than normal with
    fingerprint: 7C6B 7C5D 5E2B 6356 A926 F04F 6E3C BCE9 3372 DCFA
  + Upgraded pip to v1.4.1
  + Upgraded setuptools to v0.9.8
* Mon Jul 29 2013 speilicke@suse.com
- Don't drop shipped setuptools / pip, they've been fetched from the
  interwebs previously. It doesn't make sense to use the (currently
  matching) system equivalents, it's meant to be self-contained
* Mon Jul 29 2013 speilicke@suse.com
- Initial version
